@@ -1,8 +1,11 @@
 from psycopg_pool import AsyncConnectionPool
 from starlette.requests import Request
 
+{%- if cookiecutter.enable_taskiq == "True" %}
+from taskiq import TaskiqDepends
+{%- endif %}
 
-async def get_db_pool(request: Request) -> AsyncConnectionPool:
+async def get_db_pool(request: Request {%- if cookiecutter.enable_taskiq == "True" %} = TaskiqDepends(){%- endif %}) -> AsyncConnectionPool:
     """
     Return database connections pool.
 
