@@ -3,8 +3,12 @@ from typing import AsyncGenerator
 from sqlalchemy.ext.asyncio import AsyncSession
 from starlette.requests import Request
 
+{%- if cookiecutter.enable_taskiq == "True" %}
+from taskiq import TaskiqDepends
+{%- endif %}
 
-async def get_db_session(request: Request) -> AsyncGenerator[AsyncSession, None]:
+
+async def get_db_session(request: Request {%- if cookiecutter.enable_taskiq == "True" %} = TaskiqDepends(){%- endif %}) -> AsyncGenerator[AsyncSession, None]:
     """
     Create and get database session.
 
